<?php

$API_CONFIG = [
	'base_url' => isset($_COOKIE['url_api']) ? $_COOKIE['url_api'] : '',
	'client_id' => isset($_COOKIE['client_id']) ? $_COOKIE['client_id'] : '',
	'client_secret' => isset($_COOKIE['client_secret']) ? $_COOKIE['client_secret'] : '',
	'endpoints' => [
		'auth' => '',
		'clientes' => 'cliente/listagem',
		'online' => 'cliente/online'
	]
];

function makeApiCall($url, $headers, $method = 'GET') {

	$curl = curl_init();
	
	$options = [
		CURLOPT_URL => $url,
		CURLOPT_RETURNTRANSFER => true,
		CURLOPT_SSL_VERIFYPEER => false,
		CURLOPT_SSL_VERIFYHOST => false,
		CURLOPT_CUSTOMREQUEST => $method,
		CURLOPT_HTTPHEADER => $headers,
		CURLOPT_TIMEOUT => 30,
		CURLOPT_CONNECTTIMEOUT => 10
	];
	
	curl_setopt_array($curl, $options);
	
	$response = curl_exec($curl);
	$http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
	$error = curl_error($curl);
	
	curl_close($curl);
	
	if ($error || $http_code >= 400) {
		http_response_code(500);
		echo json_encode(['error' => 'API request failed', 'details' => $error, 'http_code' => $http_code]);
		exit;
	}
	
	return $response;

}

$auth_headers = ['Authorization: Basic ' . base64_encode($API_CONFIG['client_id'] . ':' . $API_CONFIG['client_secret'])];

$token_response = makeApiCall($API_CONFIG['base_url'] . $API_CONFIG['endpoints']['auth'], $auth_headers);
$token = $token_response;

$bearer_headers = ['Authorization: Bearer ' . $token];

// Full clientes
$clientes_response = makeApiCall($API_CONFIG['base_url'] . $API_CONFIG['endpoints']['clientes'], $bearer_headers);
$clientes = json_decode($clientes_response, true);

if (!isset($clientes['clientes'])) {
	throw new Exception('Estrutura de dados de clientes invalidos');
}

// Online clientes
$onlines_response = makeApiCall($API_CONFIG['base_url'] . $API_CONFIG['endpoints']['online'], $bearer_headers);
$onlines = @json_decode($onlines_response, true);

$marcas_full = [];
$marcas_on = [];

if (is_array($onlines) && isset($onlines['clientes'])) {
    $marcas_on = array_column($onlines['clientes'], 'login');
}

foreach ($clientes['clientes'] as $cliente) {

	if ($cliente['cli_ativado'] != 's') {
		continue;
	}

	if (empty($cliente['coordenadas'])) {
		continue;
	}
	
	$coords = explode(',', $cliente['coordenadas']);
	if (count($coords) !== 2) {
		continue;
	}
	
	list($latitude, $longitude) = $coords;
	$latitude = trim($latitude);
	$longitude = trim($longitude);
	
	if (!is_numeric($latitude) || !is_numeric($longitude)) {
		continue;
	}

	$conteudo = sprintf(
		"<strong>Nome:</strong> %s<br><strong>Login:</strong> %s<br><strong>Endereco:</strong> %s",
		htmlspecialchars($cliente['nome'] ?? 'N/A'),
		htmlspecialchars($cliente['login'] ?? 'N/A'),
		htmlspecialchars($cliente['endereco'] ?? 'N/A')
	);
	
	$marcas_full[] = [
		'latitude' => $latitude,
		'longitude' => $longitude,
		'title' => $cliente['codigo'] ?? 'Sem codigo',
		'login' => $cliente['login'] ?? 'N/A',
		'content' => $conteudo,
		'icone' => in_array($cliente['login'] ?? '', $marcas_on) ? 'online.png' : 'offline.png'
	];

}

header('Content-Type: application/json; charset=utf-8');
echo json_encode(['markers' => $marcas_full], JSON_PRETTY_PRINT);
